==> haskell-cryptohash-conduit-0.1.1-312-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-3XHZKAAibyz3jTn8IhJvwM
key: cryptohash-conduit-0.1.1-3XHZKAAibyz3jTn8IhJvwM
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: b1cb6d1cd2497509a8e3026c9390a171
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-3XHZKAAibyz3jTn8IhJvwM
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-1gVzBfuoPB16x0VLumm9wr
    conduit-extra-1.3.4-6NaiUbjHndnHOYld8wr8ov
    cryptohash-0.11.9-CoTMowpthlAFX290whuknU
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-313-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-HdPD43GAiElH26K0RHNLYa
key: cryptohash-conduit-0.1.1-HdPD43GAiElH26K0RHNLYa
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: 09e93217549628be92fac0d065f065ce
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-HdPD43GAiElH26K0RHNLYa
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-223VZeefHKZIaNcv3a4V93
    conduit-extra-1.3.4-GNv58rt6JAeUYsVx1bztm
    cryptohash-0.11.9-CoTMowpthlAFX290whuknU
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
